@@ -65,7 +65,6 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Cambridge, MA 02110-1301, USA
 #include <lib/gvdebug.h>
 #include <lib/gwenviewconfig.h>
 #include <lib/mimetypeutils.h>
-#include <lib/signalblocker.h>
 #include <lib/urlutils.h>
 #include <lib/thumbnailview/dragpixmapgenerator.h>
 #include <lib/thumbnailprovider/thumbnailprovider.h>
@@ -162,15 +161,15 @@ struct DocumentViewPrivate
                 adapter->setScrollPos(mSetup.position);
             }
         }
-        q->adapterChanged();
-        q->positionChanged();
+        emit q->adapterChanged();
+        emit q->positionChanged();
         if (adapter->canZoom()) {
             if (adapter->zoomToFit()) {
-                q->zoomToFitChanged(true);
+                emit q->zoomToFitChanged(true);
             } else if (adapter->zoomToFill()) {
-                q->zoomToFillChanged(true);
+                emit q->zoomToFillChanged(true);
             } else {
-                q->zoomChanged(adapter->zoom());
+                emit q->zoomChanged(adapter->zoom());
             }
         }
         if (adapter->rasterImageView()) {
@@ -186,7 +185,7 @@ struct DocumentViewPrivate
         floater->setChildWidget(mLoadingIndicator);
     }
 
-    HudButton* createHudButton(const QString& text, const char* iconName, bool showText)
+    HudButton* createHudButton(const QString& text, const QString &iconName, bool showText)
     {
         HudButton* button = new HudButton;
         if (showText) {
@@ -200,8 +199,8 @@ struct DocumentViewPrivate
 
     void setupHud()
     {
-        HudButton* trashButton = createHudButton(i18nc("@info:tooltip", "Trash"), "user-trash", false);
-        HudButton* deselectButton = createHudButton(i18nc("@action:button", "Deselect"), "list-remove", true);
+        HudButton* trashButton = createHudButton(i18nc("@info:tooltip", "Trash"), QStringLiteral("user-trash"), false);
+        HudButton* deselectButton = createHudButton(i18nc("@action:button", "Deselect"), QStringLiteral("list-remove"), true);
 
         QGraphicsWidget* content = new QGraphicsWidget;
         QGraphicsLinearLayout* layout = new QGraphicsLinearLayout(content);
@@ -246,12 +245,12 @@ struct DocumentViewPrivate
         QSize size = doc->size();
         if (size.isValid()) {
             caption +=
-                QString(" - %1x%2")
+                QStringLiteral(" - %1x%2")
                 .arg(size.width())
                 .arg(size.height());
             if (mAdapter->canZoom()) {
                 int intZoom = qRound(mAdapter->zoom() * 100);
-                caption += QString(" - %1%")
+                caption += QStringLiteral(" - %1%")
                            .arg(intZoom);
             }
         }
@@ -297,7 +296,7 @@ struct DocumentViewPrivate
         }
         mZoomSnapValues << MAXIMUM_ZOOM_VALUE;
 
-        q->minimumZoomChanged(min);
+        emit q->minimumZoomChanged(min);
     }
 
     void showLoadingIndicator()
@@ -346,7 +345,7 @@ struct DocumentViewPrivate
         QObject::connect(anim, SIGNAL(finished()), q, SIGNAL(isAnimatedChanged()));
         anim->setDuration(DocumentView::AnimDuration);
         mFadeAnimation = anim;
-        q->isAnimatedChanged();
+        emit q->isAnimatedChanged();
         anim->start(QAbstractAnimation::DeleteWhenStopped);
     }
 
@@ -698,7 +697,7 @@ void DocumentView::zoomOut(QPointF center)
 void DocumentView::slotZoomChanged(qreal zoom)
 {
     d->updateCaption();
-    zoomChanged(zoom);
+    emit zoomChanged(zoom);
 }
 
 void DocumentView::setZoom(qreal zoom)
@@ -733,27 +732,31 @@ void DocumentView::mousePressEvent(QGraphicsSceneMouseEvent* event)
 
 void DocumentView::wheelEvent(QGraphicsSceneWheelEvent* event)
 {
-    if (d->mAdapter->canZoom() && event->modifiers() & Qt::ControlModifier) {
-        d->controlWheelAccumulatedDelta += event->delta();
-        // Ctrl + wheel => zoom in or out
-        if (d->controlWheelAccumulatedDelta >= QWheelEvent::DefaultDeltasPerStep) {
-            zoomIn(event->pos());
-            d->controlWheelAccumulatedDelta = 0;
-        } else if (d->controlWheelAccumulatedDelta <= -QWheelEvent::DefaultDeltasPerStep) {
-            zoomOut(event->pos());
-            d->controlWheelAccumulatedDelta = 0;
+    if (d->mAdapter->canZoom()) {
+        if ((event->modifiers() & Qt::ControlModifier) ||
+            (GwenviewConfig::mouseWheelBehavior() == MouseWheelBehavior::Zoom
+            && event->modifiers() == Qt::NoModifier)) {
+            d->controlWheelAccumulatedDelta += event->delta();
+            // Ctrl + wheel => zoom in or out
+            if (d->controlWheelAccumulatedDelta >= QWheelEvent::DefaultDeltasPerStep) {
+                zoomIn(event->pos());
+                d->controlWheelAccumulatedDelta = 0;
+            } else if (d->controlWheelAccumulatedDelta <= -QWheelEvent::DefaultDeltasPerStep) {
+                zoomOut(event->pos());
+                d->controlWheelAccumulatedDelta = 0;
+            }
+            return;
         }
-        return;
     }
     if (GwenviewConfig::mouseWheelBehavior() == MouseWheelBehavior::Browse
         && event->modifiers() == Qt::NoModifier) {
         d->controlWheelAccumulatedDelta += event->delta();
         // Browse with mouse wheel
         if (d->controlWheelAccumulatedDelta >= QWheelEvent::DefaultDeltasPerStep) {
-            previousImageRequested();
+            emit previousImageRequested();
             d->controlWheelAccumulatedDelta = 0;
         } else if (d->controlWheelAccumulatedDelta <= -QWheelEvent::DefaultDeltasPerStep) {
-            nextImageRequested();
+            emit nextImageRequested();
             d->controlWheelAccumulatedDelta = 0;
         }
         return;
@@ -774,7 +777,7 @@ void DocumentView::contextMenuEvent(QGraphicsSceneContextMenuEvent* event)
     // Filter out context menu if Ctrl is down to avoid showing it when
     // zooming out with Ctrl + Right button
     if (event->modifiers() != Qt::ControlModifier) {
-        contextMenuRequested();
+        emit contextMenuRequested();
     }
 }
 
@@ -866,17 +869,17 @@ QUrl DocumentView::url() const
 
 void DocumentView::emitHudDeselectClicked()
 {
-    hudDeselectClicked(this);
+    emit hudDeselectClicked(this);
 }
 
 void DocumentView::emitHudTrashClicked()
 {
-    hudTrashClicked(this);
+    emit hudTrashClicked(this);
 }
 
 void DocumentView::emitFocused()
 {
-    focused(this);
+    emit focused(this);
 }
 
 void DocumentView::setGeometry(const QRectF& rect)
@@ -904,7 +907,7 @@ void DocumentView::moveToAnimated(const QRect& rect)
     anim->setDuration(DocumentView::AnimDuration);
     connect(anim, SIGNAL(finished()), SIGNAL(isAnimatedChanged()));
     d->mMoveAnimation = anim;
-    isAnimatedChanged();
+    emit isAnimatedChanged();
     anim->start(QAbstractAnimation::DeleteWhenStopped);
 }
 
@@ -921,7 +924,7 @@ void DocumentView::fadeOut()
 
 void DocumentView::slotFadeInFinished()
 {
-    fadeInFinished(this);
+    emit fadeInFinished(this);
 }
 
 bool DocumentView::isAnimated() const
